@@ -61,14 +61,14 @@ void DomParser::parse_file(const Glib::ustring& filename)
   parse_context();
 }
 
-void DomParser::parse_memory(const Glib::ustring& contents)
+void DomParser::parse_memory_raw(const unsigned char* contents, size_type bytes_count)
 {
   release_underlying(); //Free any existing document.
 
   KeepBlanks k(KeepBlanks::Default);
 
   //The following is based on the implementation of xmlParseFile(), in xmlSAXParseFileWithData():
-  context_ = xmlCreateMemoryParserCtxt(contents.c_str(), contents.size());
+  context_ = xmlCreateMemoryParserCtxt((const char*)contents, bytes_count);
 
   if(!context_)
   {
@@ -78,6 +78,11 @@ void DomParser::parse_memory(const Glib::ustring& contents)
   parse_context();
 }
 
+void DomParser::parse_memory(const Glib::ustring& contents)
+{
+  parse_memory_raw((const unsigned char*)contents.c_str(), contents.bytes());
+}
+
 void DomParser::parse_context()
 {
   KeepBlanks k(KeepBlanks::Default);
@@ -145,7 +150,7 @@ void DomParser::parse_stream(std::istream& in)
     // about layout in certain cases.
     line += '\n';
 
-    xmlParseChunk(context_, line.c_str(), line.length(), 0);
+    xmlParseChunk(context_, line.c_str(), line.size() /* This is a std::string, not a ustring, so this is the number of bytes. */, 0);
   }
 
   xmlParseChunk(context_, 0, 0, 1);
